Daemon

Struct Daemon 

pub struct Daemon { /* private fields */ }
The daemon holds the list of the synchronized folders, and synchronize them regularly.

It can be queried by client applications through the Server.

Implementations

Source

impl Daemon

pub async fn new(config: DaemonConfig) -> Result<Self>

pub fn stop(&self)

Requests to stop the running daemon

pub async fn spawn(self: &Arc<Self>) -> JoinHandle<Result<()>>

Spawns a new tokio task and runs the daemon inside it

pub async fn run(self: Arc<Self>) -> Result<()>

Handles client connections and periodically synchronize filesystems

pub async fn serve(&self)

Starts a new rpc server that will handle incoming requests from client applications

pub fn is_running(&self) -> bool

Returns true if the server is running

pub fn synchro_list(&self) -> ReadWriteSynchroList

The list of the synchronized fs

pub async fn recv_user_commands(&self) -> Option<UserCommand>

Receives messages of client applications

pub async fn create_synchro( &self, synchro: SynchroCreationRequest, ) -> Result<()>

Creates a new synchro

pub async fn delete_synchro( &self, synchro: SynchroDeletionRequest, ) -> Result<()>

Deletes a synchro

pub async fn update_synchro_state( &self, state_request: StateChangeRequest, ) -> Result<()>

pub async fn handle_user_commands(&self, command: UserCommand) -> Result<()>

Handles messages of client applications