pub struct Database { /* private fields */ }Expand description
A connection to the database
Implementations
Sourceimpl Database
impl Database
pub async fn insert_vfs_root(&self) -> Result<i32, DatabaseError>
Sourcepub async fn load_vfs<SyncInfo: DeserializeOwned + Debug>(
&self,
fs_uuid: Uuid,
) -> Result<Vfs<SyncInfo>, DatabaseError>
pub async fn load_vfs<SyncInfo: DeserializeOwned + Debug>( &self, fs_uuid: Uuid, ) -> Result<Vfs<SyncInfo>, DatabaseError>
Loads a vfs with all its node from the DB
Sourcepub async fn update_vfs_node_state<SyncInfo: Serialize>(
&self,
fs_uuid: Uuid,
path: &VirtualPath,
node_state: &NodeState<SyncInfo>,
) -> Result<(), DatabaseError>
pub async fn update_vfs_node_state<SyncInfo: Serialize>( &self, fs_uuid: Uuid, path: &VirtualPath, node_state: &NodeState<SyncInfo>, ) -> Result<(), DatabaseError>
Updates the state of the node at path inside the FS with id fs_uuid
Sourcepub async fn delete_vfs_node(
&self,
fs_uuid: Uuid,
path: &VirtualPath,
) -> Result<(), DatabaseError>
pub async fn delete_vfs_node( &self, fs_uuid: Uuid, path: &VirtualPath, ) -> Result<(), DatabaseError>
Removes from the DB the node at path inside the FS with id fs_uuid
Sourcepub async fn update_vfs<SyncInfo: Serialize>(
&self,
fs_uuid: Uuid,
update: &VfsUpdate<SyncInfo>,
) -> Result<(), DatabaseError>
pub async fn update_vfs<SyncInfo: Serialize>( &self, fs_uuid: Uuid, update: &VfsUpdate<SyncInfo>, ) -> Result<(), DatabaseError>
Applies a VFS update to the nodes in the DB
Sourceimpl Database
impl Database
Sourcepub async fn new(config: &DatabaseConfig) -> Result<Self, DatabaseCreationError>
pub async fn new(config: &DatabaseConfig) -> Result<Self, DatabaseCreationError>
Creates a new empty database from the config
Sourcepub async fn insert_new_filesystem(
&self,
fs_uuid: Uuid,
fs: &AnyFsCreationInfo,
) -> Result<i32, DatabaseError>
pub async fn insert_new_filesystem( &self, fs_uuid: Uuid, fs: &AnyFsCreationInfo, ) -> Result<i32, DatabaseError>
Inserts a new filesystem in the db
Sourcepub async fn delete_filesystem(
&self,
fs: &AnyFsRef,
) -> Result<(), DatabaseError>
pub async fn delete_filesystem( &self, fs: &AnyFsRef, ) -> Result<(), DatabaseError>
Deletes a single filesystem from the db
Sourcepub async fn set_synchro_status(
&self,
synchro: SynchroId,
synchro_status: SynchroStatus,
) -> Result<(), DatabaseError>
pub async fn set_synchro_status( &self, synchro: SynchroId, synchro_status: SynchroStatus, ) -> Result<(), DatabaseError>
Updates the (status)SynchroStatus of a synchro
Sourcepub async fn set_synchro_state(
&self,
synchro: SynchroId,
synchro_state: SynchroState,
) -> Result<(), DatabaseError>
pub async fn set_synchro_state( &self, synchro: SynchroId, synchro_state: SynchroState, ) -> Result<(), DatabaseError>
Updates the state of a synchro
Sourcepub async fn load_all_synchros(&self) -> Result<SynchroList, DatabaseError>
pub async fn load_all_synchros(&self) -> Result<SynchroList, DatabaseError>
Loads all the Synchros from the DB and create a new SynchroList
Sourcepub async fn insert_synchro(
&self,
created: CreatedSynchro,
info: AnySynchroCreationInfo,
) -> Result<i32, DatabaseError>
pub async fn insert_synchro( &self, created: CreatedSynchro, info: AnySynchroCreationInfo, ) -> Result<i32, DatabaseError>
Insert a new Synchro in the DB
Sourcepub async fn delete_synchro(
&self,
synchro: SynchroId,
) -> Result<(), DatabaseError>
pub async fn delete_synchro( &self, synchro: SynchroId, ) -> Result<(), DatabaseError>
Deletes a Synchro from the DB