pub struct Server { /* private fields */ }Expand description
A Server that handle RPC connections from client applications
The server and the Daemon are running in separate tasks to be able to give a quick feedback
to client applications even when a synchronization is in progress.