pub struct ReadWriteSynchroList { /* private fields */ }Expand description
A SynchroList that allows read-write access and can be shared between threads.
Implementations
Sourceimpl ReadWriteSynchroList
impl ReadWriteSynchroList
pub async fn read(&self) -> RwLockReadGuard<'_, SynchroList>
Sourcepub async fn insert(
&self,
sync_info: AnySynchroCreationInfo,
) -> Result<CreatedSynchro, SynchroCreationError>
pub async fn insert( &self, sync_info: AnySynchroCreationInfo, ) -> Result<CreatedSynchro, SynchroCreationError>
Inserts a new synchronized pair of filesystem in the list
Sourcepub async fn remove(&self, id: SynchroId) -> Result<(), SynchroDeletionError>
pub async fn remove(&self, id: SynchroId) -> Result<(), SynchroDeletionError>
Deletes a synchronization from the list
Sourcepub async fn sync_all(&self, db: &Database) -> Vec<Result<(), SyncError>>
pub async fn sync_all(&self, db: &Database) -> Vec<Result<(), SyncError>>
Forces a synchro of all the filesystems in the list, and updates the db accordingly
Sourcepub async fn resolve_conflict(
&self,
id: SynchroId,
path: &VirtualPath,
side: SynchroSide,
db: &Database,
) -> Result<(), SyncError>
pub async fn resolve_conflict( &self, id: SynchroId, path: &VirtualPath, side: SynchroSide, db: &Database, ) -> Result<(), SyncError>
Resolves a conflict on a path inside a synchro, by applying the update from side.
Updates the db accordingly
Sourcepub fn as_read_only(&self) -> ReadOnlySynchroList
pub fn as_read_only(&self) -> ReadOnlySynchroList
Returns a read-only view of the list
pub async fn len(&self) -> usize
pub async fn is_empty(&self) -> bool