pub struct Daemon { /* private fields */ }Expand description
The daemon holds the list of the synchronized folders, and synchronize them regularly.
It can be queried by client applications through the Server.
Implementations
Sourceimpl Daemon
impl Daemon
pub async fn new(config: DaemonConfig) -> Result<Self>
Sourcepub async fn spawn(self: &Arc<Self>) -> JoinHandle<Result<()>>
pub async fn spawn(self: &Arc<Self>) -> JoinHandle<Result<()>>
Spawns a new tokio task and runs the daemon inside it
Sourcepub async fn run(self: Arc<Self>) -> Result<()>
pub async fn run(self: Arc<Self>) -> Result<()>
Handles client connections and periodically synchronize filesystems
Sourcepub async fn serve(&self)
pub async fn serve(&self)
Starts a new rpc server that will handle incoming requests from client applications
Sourcepub fn is_running(&self) -> bool
pub fn is_running(&self) -> bool
Returns true if the server is running
Sourcepub fn synchro_list(&self) -> ReadWriteSynchroList
pub fn synchro_list(&self) -> ReadWriteSynchroList
The list of the synchronized fs
Sourcepub async fn recv_user_commands(&self) -> Option<UserCommand>
pub async fn recv_user_commands(&self) -> Option<UserCommand>
Receives messages of client applications
Sourcepub async fn create_synchro(
&self,
synchro: SynchroCreationRequest,
) -> Result<()>
pub async fn create_synchro( &self, synchro: SynchroCreationRequest, ) -> Result<()>
Creates a new synchro
Sourcepub async fn delete_synchro(
&self,
synchro: SynchroDeletionRequest,
) -> Result<()>
pub async fn delete_synchro( &self, synchro: SynchroDeletionRequest, ) -> Result<()>
Deletes a synchro
pub async fn update_synchro_state( &self, state_request: StateChangeRequest, ) -> Result<()>
Sourcepub async fn handle_user_commands(&self, command: UserCommand) -> Result<()>
pub async fn handle_user_commands(&self, command: UserCommand) -> Result<()>
Handles messages of client applications